using BPA.SAAS.Manage.Application.Org.Dtos.Users;
using BPA.SAAS.Manage.Core.Base;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace BPA.SAAS.Manage.Application.Org.Interface
{
    public interface IUserService
    {
        Task<PageUtil> UserPage(UserDtoPageInput input);
        Task<bool> AddUser(UserDtoInput input);
        Task<bool> UpdateUser(UserDtoInput input);
        Task<bool> DeleteUser(List<string> input);
        Task<bool> Enable(string Id);
        Task<bool> Disable(string Id);
        Task<bool> ResetPwd(string Id);
        Task<bool> UpdatePwd(UserPwdDtoInput input);
        Task<UserRoleDtoInput> GetUserRole(string UserId);
        Task<bool> AddUserRole(UserRoleDtoInput input);
    }
}
